Crate kcr_app_redislabs_com

Crate kcr_app_redislabs_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the app.redislabs.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

app.redislabs.com/v1

  • RedisEnterpriseCluster

app.redislabs.com/v1alpha1

  • RedisEnterpriseActiveActiveDatabase
  • RedisEnterpriseCluster
  • RedisEnterpriseDatabase
  • RedisEnterpriseRemoteCluster

Modules

v1
v1alpha1